# whatchamacallit

Use web resources the pythonic way. Specify Javascript modules, HTML, CSS as bare URLs and rewrite on the fly.

# Examples


# Configure Poetry

````shell script
poetry publish
````


# Build

````shell script
poetry build
````

# Publishing to PyPI

````shell script
poetry publish
````

# Previous Work


# Bundlers:
# Unpkg.com, rollup, webpack, babel, pika, assetgraph, Browserify, gulp, JSPM
# In Place:
# snowflake, Open Web Components, browser sync, es-module-shims
# See
#   http://dplatz.de/blog/2019/es6-bare-imports.html
#   https://jakearchibald.com/2017/es-modules-in-browsers/
#   https://medium.com/@dmnsgn/in-2020-go-bundler-free-eb29c1f05fc9
#   https://wicg.github.io/import-maps/
#   https://medium.com/@dmnsgn/es-modules-in-the-browser-almost-now-3638ffafdc68
